@@ -4,7 +4,12 @@ from pywood.updates.commands import is_command
 from pywood.updates.numbers import is_int_number
 from pywood.updates.texts import is_msg_w_text_to_bot
 
-__all__ = ['IncomingText', 'IncomingCommand', 'IncomingIntNumber']
+__all__ = [
+    'IncomingText',
+    'IncomingCommand',
+    'IncomingIntNumber',
+    'IncomingUpdate'
+]
 
 
 class IncomingText(BaseEvent):
@@ -15,6 +20,14 @@ class IncomingText(BaseEvent):
         return is_msg_w_text_to_bot(update)
 
 
+class IncomingUpdate(BaseEvent):
+    """Любое входящее обновление."""
+
+    @staticmethod
+    def happened(update) -> bool:
+        return True
+
+
 class IncomingCommand(BaseEvent):
     """Входящая команда."""
 
